"""Check for Execution-Time information"""

import re

def executionRegexp():
    """@Return: The regular expression that parses the execution time
    depending on the OpenFOAM-Version"""
    
    if foamVersionNumber()>=(1,3):
        return "^ExecutionTime = (.+) s  ClockTime = (.+) s$"
    else:
        return "^ExecutionTime = (.+) s$"

from FileLineAnalyzer import FileLineAnalyzer
from TimeLineLineAnalyzer import TimeLineLineAnalyzer

from PyFoam.FoamInformation import foamVersionNumber

class ExecutionTimeLineAnalyzer(FileLineAnalyzer):
    """Parses lines for the execution time"""
    
    def __init__(self):
        FileLineAnalyzer.__init__(self,titles=["ExecutionTime"])
        self.exp=re.compile(executionRegexp())
        
    def doAnalysis(self,line):
        """Writes total execution time and time needed since last
        time-step"""
        m=self.exp.match(line)
        if m!=None:
            time=float(m.group(1))
            
            self.files.write("executionTime",self.parent.getTime(),(time,time-self.lastTime))

            self.lastTime = time
    
class TimeLineExecutionTimeLineAnalyzer(TimeLineLineAnalyzer):
    """Parses lines for the execution time"""
    
    def __init__(self):
        TimeLineLineAnalyzer.__init__(self)
        
        self.hasClock=(foamVersionNumber()>=(1,3))

        self.exp=re.compile(executionRegexp())
        
        self.lastTime=0.
        if self.hasClock:
            self.lastClock=0.
            
    def doAnalysis(self,line):
        """Writes total execution time and time needed since last
        time-step"""
        m=self.exp.match(line)
        if m!=None:
            time=float(m.group(1))
            if self.hasClock:
                clock=float(m.group(2))
                
            self.lines.setValue("cpu",time-self.lastTime)
            self.lastTime = time

            if self.hasClock:
                self.lines.setValue("clock",clock-self.lastClock)
                self.lastClock = clock
            
    
