"""Analyze standard solver"""

from FoamLogAnalyzer import FoamLogAnalyzer

from ContinuityLineAnalyzer import ContinuityLineAnalyzer,TimeLineContinuityLineAnalyzer
from LinearSolverLineAnalyzer import LinearSolverLineAnalyzer,TimeLineLinearSolverLineAnalyzer,TimeLineLinearIterationsSolverLineAnalyzer
from ExecutionTimeLineAnalyzer import ExecutionTimeLineAnalyzer,TimeLineExecutionTimeLineAnalyzer

class StandardLogAnalyzer(FoamLogAnalyzer):
    """
    The analyzer for the most common OpenFOAM solvers

    It checks:
     - Continuity
     - the Linear solvers
     - Execution time
    """
    def __init__(self,progress=False):
        """
        @param progress: Print time progress on console?
        """
        FoamLogAnalyzer.__init__(self,progress=progress)

        self.addAnalyzer("Continuity",ContinuityLineAnalyzer())
        self.addAnalyzer("Linear",LinearSolverLineAnalyzer())
        self.addAnalyzer("Execution",ExecutionTimeLineAnalyzer())

class StandardPlotLogAnalyzer(FoamLogAnalyzer):
    """This analyzer checks the current residuals and generates timelines"""
    def __init__(self):
        FoamLogAnalyzer.__init__(self,progress=True)
        
        self.addAnalyzer("PlotContinuity",TimeLineContinuityLineAnalyzer())
        self.addAnalyzer("PlotLinear",TimeLineLinearSolverLineAnalyzer())
        self.addAnalyzer("PlotIterations",TimeLineLinearIterationsSolverLineAnalyzer())
        self.addAnalyzer("PlotExecution",TimeLineExecutionTimeLineAnalyzer())
        
