#! /usr/bin/env python 

description="""
Gets the name of a logfile which is assumed to be the output of a
OpenFOAM-solver. Parses the logfile for information about the
convergence of the solver and generates gnuplot-graphs. Watches the
file until interrupted.
"""

from PyFoam.Basics.FoamOptionParser import FoamOptionParser

parse=FoamOptionParser(description=description,usage="%prog [options] <logfile>",interspersed=True)

parse.add_option("--frequency",type="float",dest="frequency",default=1.,help="The frequency with which output should be generated (in seconds)")
parse.add_option("--persist",action="store_true",dest="persist",default=True,help="Gnuplot windows stay after interrupt")
parse.add_option("--non-persist",action="store_false",dest="persist",help="Gnuplot windows close after interrupt")
parse.add_option("--tail",type="long",dest="tail",default=1000L,help="The length at the end of the file that should be output (in bytes)")
parse.add_option("--silent",action="store_true",dest="silent",default=False,help="Logfile is not copied to the terminal")
parse.add_option("--no-linear",action="store_false",default=True,dest="linear",help="Don't plot the linear solver convergence")
parse.add_option("--no-continuity",action="store_false",default=True,dest="cont",help="Don't plot the continuity info")
parse.add_option("--no-bound",action="store_false",default=True,dest="bound",help="Don't plot the bounding of variables")
parse.add_option("--with-iterations",action="store_true",default=False,dest="iterations",help="Plot the number of iterations of the linear solver")
parse.add_option("--with-courant",action="store_true",default=False,dest="courant",help="Plot the courant-numbers of the flow")
parse.add_option("--with-execution",action="store_true",default=False,dest="execution",help="Plot the execution time of each time-step")

parse.parse(nr=1)
    
from PyFoam.Execution.GnuplotRunner import GnuplotWatcher

opts=parse.getOptions()

run=GnuplotWatcher(parse.getArgs()[0],smallestFreq=opts.frequency,persist=opts.persist,tailLength=opts.tail,silent=opts.silent,plotLinear=opts.linear,plotCont=opts.cont,plotBound=opts.bound,plotIterations=opts.iterations,plotCourant=opts.courant,plotExecution=opts.execution)

run.start()
